@@ -1,25 +1,30 @@
 #' Arrange plots in a grid
 #'
-#' The \code{bayesplot_grid} function makes it simple to juxtapose plots using
+#' The `bayesplot_grid` function makes it simple to juxtapose plots using
 #' common \eqn{x} and/or \eqn{y} axes.
 #'
 #' @export
 #' @param ... One or more ggplot objects.
 #' @param plots A list of ggplot objects. Can be used as an alternative to
-#'   specifying plot objects via \code{...}.
+#'   specifying plot objects via `...`.
 #' @param grid_args An optional named list of arguments to pass to
-#'   \code{\link[gridExtra]{arrangeGrob}} (\code{nrow}, \code{ncol},
-#'   \code{widths}, etc.).
+#'   [gridExtra::arrangeGrob()] (`nrow`, `ncol`,
+#'   `widths`, etc.).
 #' @param titles,subtitles Optional character vectors of plot titles and
-#'   subtitles. If specified, \code{titles} and \code{subtitles} must must have
+#'   subtitles. If specified, `titles` and `subtitles` must must have
 #'   length equal to the number of plots specified.
 #' @param xlim,ylim Optionally, numeric vectors of length 2 specifying lower and
 #'   upper limits for the axes that will be shared across all plots.
 #' @param legends If any of the plots have legends should they be displayed?
-#'   Defaults to \code{TRUE}.
+#'   Defaults to `TRUE`.
+#' @param save_gg_objects If `TRUE`, the default, then the ggplot objects
+#'   specified in `...` or via the `plots` argument are saved in a
+#'   list in the `"bayesplots"` component of the returned object.
+#'   Setting this to `FALSE` will make the returned object smaller but
+#'   these individual plot objects will not be available.
 #'
-#' @return An object of class "bayesplot_grid" (essentially a gtable object from
-#'   \code{\link[gridExtra]{arrangeGrob}}), which has a \code{plot} method.
+#' @return An object of class `"bayesplot_grid"` (essentially a gtable object
+#'   from [gridExtra::arrangeGrob()]), which has a `plot` method.
 #'
 #' @examples
 #' y <- example_y_data()
@@ -37,8 +42,8 @@
 #' \dontrun{
 #' library(rstanarm)
 #' mtcars$log_mpg <- log(mtcars$mpg)
-#' fit1 <- stan_glm(mpg ~ wt, data = mtcars)
-#' fit2 <- stan_glm(log_mpg ~ wt, data = mtcars)
+#' fit1 <- stan_glm(mpg ~ wt, data = mtcars, refresh = 0)
+#' fit2 <- stan_glm(log_mpg ~ wt, data = mtcars, refresh = 0)
 #'
 #' y <- mtcars$mpg
 #' yrep1 <- posterior_predict(fit1, draws = 50)
@@ -69,21 +74,22 @@ bayesplot_grid <-
            grid_args = list(),
            titles = character(),
            subtitles = character(),
-           legends = TRUE) {
+           legends = TRUE,
+           save_gg_objects = TRUE) {
 
     suggested_package("gridExtra")
     dots <- list(...)
     if (length(dots) && length(plots)) {
-      stop("Arguments '...' and 'plots' can't both be specified.")
+      abort("Arguments '...' and 'plots' can't both be specified.")
     } else if (length(plots)) {
       if (!is.list(plots) || !all_ggplot(plots))
-        stop("'plots' must be a list of ggplot objects.")
+        abort("'plots' must be a list of ggplot objects.")
     } else if (length(dots)) {
       if (!all_ggplot(dots))
-        stop("All objects in '...' must be ggplot objects.")
+        abort("All objects in '...' must be ggplot objects.")
       plots <- dots
     } else {
-      stop("No plots specified.")
+      abort("No plots specified.")
     }
 
     if (length(titles)) {
@@ -108,6 +114,9 @@ bayesplot_grid <-
 
     grid_args$grobs <- plots
     g <- do.call(gridExtra::arrangeGrob, args = grid_args)
+    if (save_gg_objects) {
+      g$bayesplots <- plots
+    }
     as_bayesplot_grid(g)
   }
 
@@ -117,6 +126,10 @@ as_bayesplot_grid <- function(x) {
   structure(x, class = unique(c("bayesplot_grid", class(x))))
 }
 
+is_bayesplot_grid <- function(x) {
+  inherits(x, "bayesplot_grid")
+}
+
 all_ggplot <- function(x) {
   all(sapply(x, "inherits", what = "ggplot"))
 }
